@@ -130,6 +130,31 @@ ClientGroup:
 
     disable_auto_discover()         -- disables  autodiscover option at client group level
 
+ClientGroup Attributes
+-----------------------
+
+    Following attributes are available for an instance of the ClientGroup class:
+
+        **name**                       --      returns the name of client group
+        
+        **clientgroup_id**             --      returns the id of client group
+        
+        **clientgroup_name**           --      returns the name of client group
+        
+        **description**                --      returns the description of client group
+        
+        **associated_clients**         --      returns the associated clients of client group
+        
+        **is_backup_enabled**          --      returns the backup activity status of client group
+        
+        **is_restore_enabled**         --      returns the restore activity status of client group
+        
+        **is_data_aging_enabled**      --      returns the data aging activity status of client group
+        
+        **is_smart_client_group**      --      returns true if client group is a smart client group
+        
+        **is_auto_discover_enabled**   --      returns the auto discover status of client group
+        
 """
 
 from __future__ import absolute_import
@@ -138,8 +163,6 @@ from __future__ import unicode_literals
 import time
 import copy
 
-from past.builtins import basestring
-
 from .exception import SDKException
 from .network import Network
 from .network_throttle import NetworkThrottle
@@ -277,7 +300,7 @@ class ClientGroups(object):
         clients = []
 
         for client in clients_list:
-            if isinstance(client, basestring):
+            if isinstance(client, str):
                 client = client.strip().lower()
 
                 if self._commcell_object.clients.has_client(client):
@@ -310,7 +333,7 @@ class ClientGroups(object):
                 SDKException:
                     if type of the client group name argument is not string
         """
-        if not isinstance(clientgroup_name, basestring):
+        if not isinstance(clientgroup_name, str):
             raise SDKException('ClientGroup', '101')
 
         return self._clientgroups and clientgroup_name.lower() in self._clientgroups
@@ -641,14 +664,14 @@ class ClientGroups(object):
 
                     if client group already exists with the given name
         """
-        if not (isinstance(clientgroup_name, basestring) and
-                isinstance(kwargs.get('clientgroup_description', ''), basestring)):
+        if not (isinstance(clientgroup_name, str) and
+                isinstance(kwargs.get('clientgroup_description', ''), str)):
             raise SDKException('ClientGroup', '101')
 
         if not self.has_clientgroup(clientgroup_name):
             if isinstance(clients, list):
                 clients = self._valid_clients(clients)
-            elif isinstance(clients, basestring):
+            elif isinstance(clients, str):
                 clients = self._valid_clients(clients.split(','))
             else:
                 raise SDKException('ClientGroup', '101')
@@ -760,7 +783,7 @@ class ClientGroups(object):
 
                     if no client group exists with the given name
         """
-        if not isinstance(clientgroup_name, basestring):
+        if not isinstance(clientgroup_name, str):
             raise SDKException('ClientGroup', '101')
         else:
             clientgroup_name = clientgroup_name.lower()
@@ -793,7 +816,7 @@ class ClientGroups(object):
                     if no clientgroup exists with the given name
         """
 
-        if not isinstance(clientgroup_name, basestring):
+        if not isinstance(clientgroup_name, str):
             raise SDKException('ClientGroup', '101')
         else:
             clientgroup_name = clientgroup_name.lower()
@@ -880,6 +903,7 @@ class ClientGroup(object):
         self._is_backup_enabled = None
         self._is_restore_enabled = None
         self._is_data_aging_enabled = None
+        self._is_smart_client_group = None
 
         self.refresh()
 
@@ -950,6 +974,7 @@ class ClientGroup(object):
             for client in clientgroup_props['associatedClients']:
                 self._associated_clients.append(client['clientName'])
 
+        self._is_smart_client_group = self._properties['isSmartClientGroup']
         self._is_backup_enabled = False
         self._is_restore_enabled = False
         self._is_data_aging_enabled = False
@@ -1168,12 +1193,12 @@ class ClientGroup(object):
 
                     if failed to remove clients from the ClientGroup
         """
-        if isinstance(clients, (basestring, list)):
+        if isinstance(clients, (str, list)):
             clientgroups_object = ClientGroups(self._commcell_object)
 
             if isinstance(clients, list):
                 validated_clients_list = clientgroups_object._valid_clients(clients)
-            elif isinstance(clients, basestring):
+            elif isinstance(clients, str):
                 validated_clients_list = clientgroups_object._valid_clients(clients.split(','))
 
             if operation_type in ['ADD', 'OVERWRITE']:
@@ -1252,6 +1277,11 @@ class ClientGroup(object):
         """Treats the clientgroup data aging attribute as a property of the ClientGroup class."""
         return self._is_data_aging_enabled
 
+    @property
+    def is_smart_client_group(self):
+        """Returns boolean indicating whether client group is smart client group"""
+        return self._is_smart_client_group
+    
     @property
     def network(self):
         """Returns the object of Network class."""
@@ -1574,7 +1604,7 @@ class ClientGroup(object):
     @clientgroup_name.setter
     def clientgroup_name(self, value):
         """Sets the name of the clientgroup as the value provided as input."""
-        if isinstance(value, basestring):
+        if isinstance(value, str):
             output = self._update(
                 clientgroup_name=value,
                 clientgroup_description=self.description,
@@ -1594,7 +1624,7 @@ class ClientGroup(object):
     @description.setter
     def description(self, value):
         """Sets the description of the clientgroup as the value provided in input."""
-        if isinstance(value, basestring):
+        if isinstance(value, str):
             output = self._update(
                 clientgroup_name=self.name,
                 clientgroup_description=value,
