@@ -59,6 +59,8 @@ IndexServers
 
     refresh()                           --  refresh the index servers associated with commcell
 
+    prune_orphan_datasources()          --  Deletes all the orphan datasources
+
 IndexServers Attributes
 -----------------------
 
@@ -192,7 +194,6 @@ _Roles Attributes
 
 from copy import deepcopy
 import enum
-from past.builtins import basestring
 from .exception import SDKException
 from .datacube.constants import IndexServerConstants
 
@@ -372,7 +373,7 @@ class IndexServers(object):
                     SDKExecption:
                         Data type of the input(s) is not valid
         """
-        if isinstance(cloud_name, basestring):
+        if isinstance(cloud_name, str):
             for index_server in self._all_index_servers:
                 if self._all_index_servers[index_server]["engineName"].lower() == cloud_name.lower():
                     return True
@@ -403,7 +404,7 @@ class IndexServers(object):
                     self._all_index_servers[cloud_data]['engineName'],
                     cloud_data)
             SDKException('IndexServers', '102')
-        elif isinstance(cloud_data, basestring):
+        elif isinstance(cloud_data, str):
             name = cloud_data.lower()
             for itter in self._all_index_servers:
                 if self._all_index_servers[itter]['engineName'].lower(
@@ -456,9 +457,9 @@ class IndexServers(object):
                         Response was empty.
         """
         if not (isinstance(index_server_roles, list) and isinstance(index_server_node_names, list)
-                and isinstance(index_server_name, basestring)):
+                and isinstance(index_server_name, str)):
             raise SDKException('IndexServers', '101')
-        if isinstance(index_directory, basestring):
+        if isinstance(index_directory, str):
             index_directory = index_directory.split(",")
         node_count = len(index_server_node_names)
         index_directories_count = len(index_directory)
@@ -567,7 +568,7 @@ class IndexServers(object):
 
                         Response was empty.
         """
-        if not isinstance(cloud_name, basestring):
+        if not isinstance(cloud_name, str):
             raise SDKException('IndexServers', '101')
         cloud_id = self.get(cloud_name).cloud_id
         req_json = deepcopy(IndexServerConstants.REQUEST_JSON)
@@ -590,6 +591,29 @@ class IndexServers(object):
             raise SDKException('Response', '102')
         self._response_not_success(response)
 
+    def prune_orphan_datasources(self):
+        """Deletes all the orphan datasources
+            Raises:
+                SDKException:
+                    if failed to prune the orphan datasources
+
+                    If response is empty
+
+                    if response is not success
+        """
+        prune_datasource = self._services['PRUNE_DATASOURCE']
+        request_json = IndexServerConstants.PRUNE_REQUEST_JSON
+        flag, response = self._cvpysdk_object.make_request(
+            'POST', prune_datasource, request_json)
+        if flag:
+            if response.json():
+                error_code = response.json().get('errorCode', 0)
+                if error_code != 0:
+                    raise SDKException('IndexServers', '104', 'Failed to prune orphan datasources')
+                return
+            raise SDKException('Response', '102')
+        raise SDKException('Response', '101', self._update_response_(response.text))
+
 
 class IndexServerOSType(enum.Enum):
     """Enum class for Index Server OS Type"""
@@ -765,7 +789,7 @@ class IndexServer(object):
 
                             if response is not success
         """
-        if not isinstance(core_name, basestring):
+        if not isinstance(core_name, str):
             raise SDKException('IndexServers', '101')
         if self.is_cloud:
             raise SDKException('IndexServers', '104', "Not implemented for solr cloud")
