@@ -44,6 +44,8 @@ PostgreSQLInstance:
     restore_in_place()                   --     Restores the postgres data/log files
     specified in the input paths list to the same location
 
+    change_sa_password()                 --     Changes postgresql user password
+
 PostgreSQLInstance instance Attributes
 ======================================
 
@@ -82,6 +84,7 @@ PostgreSQLInstance instance Attributes
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
+from base64 import b64encode
 from ..instance import Instance
 from ..exception import SDKException
 
@@ -165,6 +168,22 @@ class PostgreSQLInstance(Instance):
         """
         return self._properties.get('postGreSQLInstance', {}).get('logStoragePolicy', {}).get('storagePolicyName', None)
 
+    @log_storage_policy.setter
+    def log_storage_policy(self, value):
+        """ Setter for log storage policy in instance property
+
+            Args:
+
+                value (str)  -- Storage policy name
+
+        """
+        if not isinstance(value, str):
+            raise SDKException('Instance', '101')
+        properties = self._properties
+        properties['postGreSQLInstance']['logStoragePolicy'] = {}
+        properties['postGreSQLInstance']['logStoragePolicy']['storagePolicyName'] = value
+        self.update_properties(properties)
+
     @property
     def postgres_server_user_name(self):
         """Returns the username of postgres server
@@ -324,6 +343,20 @@ class PostgreSQLInstance(Instance):
         properties['postGreSQLInstance']['standbyOptions']['useMasterForDataBkp'] = value
         self.update_properties(properties)
 
+    def change_sa_password(self, value):
+        """ Changes postgresql user password
+
+            Args:
+
+                value (bool)  -- PostgreSQL password
+
+        """
+        if not isinstance(value, str):
+            raise SDKException('Instance', '101')
+        properties = self._properties
+        properties['postGreSQLInstance']['SAUser']['password'] = b64encode(value.encode()).decode()
+        self.update_properties(properties)
+
     def _get_instance_properties(self):
         """Gets the properties of this instance.
 
@@ -385,14 +418,14 @@ class PostgreSQLInstance(Instance):
         super(PostgreSQLInstance, self)._restore_common_options_json(value)
         if value.get("baseline_jobid"):
             self._commonoption_restore_json = {
-                "clusterDBBackedup":False,
-                "restoreToDisk":False,
-                "baselineBackup":1,
+                "clusterDBBackedup": False,
+                "restoreToDisk": False,
+                "baselineBackup": 1,
                 "baselineRefTime": value.get("baseline_ref_time", ""),
-                "baselineJobId":value.get("baseline_jobid", ""),
-                "copyToObjectStore":False,
-                "onePassRestore":False,
-                "syncRestore":value.get("sync_restore", True)
+                "baselineJobId": value.get("baseline_jobid", ""),
+                "copyToObjectStore": False,
+                "onePassRestore": False,
+                "syncRestore": value.get("sync_restore", True)
             }
 
     def _restore_destination_json(self, value):
@@ -489,7 +522,8 @@ class PostgreSQLInstance(Instance):
             redirect_path=None,
             restore_to_disk=False,
             restore_to_disk_job=None,
-            destination_path=None):
+            destination_path=None,
+            revert=False):
         """Restores the postgres data/log files specified in the input paths
         list to the same location.
 
@@ -587,6 +621,10 @@ class PostgreSQLInstance(Instance):
 
                     default: None
 
+                revert                  (bool)  --  boolean to specify whether to do a
+                                                    hardware revert in restore
+                    default: False
+
             Returns:
                 object - instance of the Job class for this restore job
 
@@ -647,4 +685,7 @@ class PostgreSQLInstance(Instance):
             request_json['taskInfo']['subTasks'][0]['options'][
                 'restoreOptions']['destination']["destPath"] = [destination_path]
 
+        if revert:
+            request_json['taskInfo']['subTasks'][0]['options'][
+                'restoreOptions']['commonOptions']["revert"] = revert
         return self._process_restore_response(request_json)
