@@ -247,7 +247,7 @@ class _Metrics(object):
     def enable_all_services(self):
         """enables All Service"""
         for index, service in enumerate(self._service_list):
-            if service['service']['name'] != 'Post Upgrade Check':
+            if service['service']['name'] not in ['Post Upgrade Check', 'Upgrade Readiness']:
                 self._service_list[index]['enabled'] = self._enable_service
                 service_name = service['service']['name']
                 self.services[service_name] = self._enable_service
@@ -255,7 +255,7 @@ class _Metrics(object):
     def disable_all_services(self):
         """disables All Service"""
         for index, service in enumerate(self._service_list):
-            if service['service']['name'] != 'Post Upgrade Check':
+            if service['service']['name'] not in ['Post Upgrade Check', 'Upgrade Readiness']:
                 self._service_list[index]['enabled'] = self._disable_service
                 service_name = service['service']['name']
                 self.services[service_name] = self._disable_service
