@@ -72,7 +72,6 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 from cvpysdk.exception import SDKException
-from past.builtins import basestring
 
 
 class RecoveryTargets:
@@ -178,7 +177,7 @@ class RecoveryTargets:
                     if type of the target name argument is not string
 
         """
-        if not isinstance(target_name, basestring):
+        if not isinstance(target_name, str):
             raise SDKException('Target', '101')
 
         return self._recovery_targets and target_name.lower() in self._recovery_targets
@@ -199,7 +198,7 @@ class RecoveryTargets:
                     if no target exists with the given name
 
         """
-        if not isinstance(recovery_target_name, basestring):
+        if not isinstance(recovery_target_name, str):
             raise SDKException('Target', '101')
         else:
             recovery_target_name = recovery_target_name.lower()
@@ -254,10 +253,12 @@ class RecoveryTarget:
         self._destination_hypervisor = None
         self._access_node = None
         self._users = []
+        self._user_groups = []
         self._vm_prefix = ''
         self._vm_suffix = ''
 
         self._destination_host = None
+        self._vm_storage_policy = None
         self._datastore = None
         self._resource_pool = None
         self._destination_network = None
@@ -275,6 +276,7 @@ class RecoveryTarget:
         self._vm_size = None
         self._disk_type = None
         self._virtual_network = None
+        self._vm_folder = None
         self._security_group = None
         self._create_public_ip = None
         self._restore_as_managed_vm = None
@@ -318,12 +320,13 @@ class RecoveryTarget:
                 vm_name_edit_string = self._recovery_target_properties.get('vmNameEditString')
                 vm_name_edit_type = self._recovery_target_properties.get('vmNameEditType', 1)
                 if vm_name_edit_string and vm_name_edit_type == 2:
-                    self._vm_suffix = self._recovery_target_properties['vmNameEditString']
+                    self._vm_suffix = self._recovery_target_properties.get('vmNameEditString')
                 elif vm_name_edit_string and vm_name_edit_type == 1:
-                    self._vm_prefix = self._recovery_target_properties['vmNameEditString']
-                self._access_node = self._recovery_target_properties['proxyClientEntity']['clientName']
-                self._users = self._recovery_target_properties['securityAssociations']['users']
-                self._policy_type = self._recovery_target_properties["entity"]["policyType"]
+                    self._vm_prefix = self._recovery_target_properties.get('vmNameEditString')
+                self._access_node = self._recovery_target_properties.get('proxyClientEntity', {}).get('clientName')
+                self._users = self._recovery_target_properties.get('securityAssociations', {}).get('users')
+                self._user_groups = self._recovery_target_properties.get('securityAssociations', {}).get('userGroups')
+                self._policy_type = self._recovery_target_properties.get("entity", {}).get("policyType")
 
                 if self._policy_type == 1:
                     self._availability_zone = (self._recovery_target_properties.get('amazonPolicy',{}).get('availabilityZones', [{}])[0].get('availabilityZoneName', None))
@@ -342,7 +345,7 @@ class RecoveryTarget:
                     self._test_virtual_network = self._recovery_target_properties.get('networkInfo', [{}])[0].get('label', None)
                     self._test_security_group = self._recovery_target_properties.get('testSecurityGroups', [{}])[0].get('name', '')
                     self._test_vm_size = (self._recovery_target_properties.get('amazonPolicy', {}).get('vmInstanceTypes', [{}])[0].get('vmInstanceTypeName',''))
-                    
+
                 elif self._policy_type == 2:
                     self._vm_folder = self._recovery_target_properties['dataStores'][0]['dataStoreName']
                     self._destination_network = self._recovery_target_properties['networkList'][0]['networkName']
@@ -377,6 +380,7 @@ class RecoveryTarget:
                     self._vm_folder = self._recovery_target_properties['folderPath']
                     self._destination_network = self._recovery_target_properties['networkList'][0]['destinationNetwork']
 
+                    self._vm_storage_policy = self._recovery_target_properties.get('vmStoragePolicyName')
                     expiry_hours = self._recovery_target_properties.get("minutesRetainUntil")
                     expiry_days = self._recovery_target_properties.get("daysRetainUntil")
                     if expiry_hours:
@@ -458,6 +462,11 @@ class RecoveryTarget:
         """Returns: (str) VMware: the destination ESX host name"""
         return self._destination_host
 
+    @property
+    def vm_storage_policy(self):
+        """Returns: (str) VMware: the vm storage policy name"""
+        return self._vm_storage_policy
+
     @property
     def datastore(self):
         """Returns: (str) VMware: the datastore name"""
